@@ -7,12 +7,16 @@
  * http://arrayfire.com/licenses/BSD-3-Clause
  ********************************************************/
 
+#pragma once
+
 #include <string>
 
 namespace cpu {
+    class queue;
+
     int getBackend();
 
-    std::string getInfo();
+    std::string getDeviceInfo();
 
     bool isDoubleSupported(int device);
 
@@ -24,5 +28,13 @@ namespace cpu {
 
     int getActiveDeviceId();
 
+    size_t getDeviceMemorySize(int device);
+
+    size_t getHostMemorySize();
+
     void sync(int device);
+
+    queue& getQueue(int idx = 0);
+
+    unsigned getMaxJitSize();
 }
