@@ -12,6 +12,8 @@
 #include <identity.hpp>
 
 #if defined(WITH_OPENCL_LINEAR_ALGEBRA)
+#include <platform.hpp>
+#include <cpu/cpu_inverse.hpp>
 
 namespace opencl
 {
@@ -19,6 +21,10 @@ namespace opencl
 template<typename T>
 Array<T> inverse(const Array<T> &in)
 {
+    if(OpenCLCPUOffload()) {
+        if (in.dims()[0] == in.dims()[1])
+            return cpu::inverse(in);
+    }
     Array<T> I = identity<T>(in.dims());
     return solve<T>(in, I);
 }
